Learn R Programming

kmi (version 0.5.5)

icu.pneu: Hospital acquired penumonia in ICU

Description

This data set is a random sample drawn from the SIR-3 study that aimed at analysing the effect of nosocomial infections on the length of ICU stay. Patients were included in the study if they had stayed at least 1 day in the unit. The sample includes information to assess the effect of nosocomial pneumonia on the length of stay. The endpoint is either discharge alive from the ICU or dead in the unit. These data are censoring complete as the censoring time is known for all patients.

Usage

data(icu.pneu)

Arguments

Format

A data frame with 1421 observations on the following 8 variables.

id

Individual patient id.

start

Start of the observation time.

stop

Failure time.

status

Censoring status. 0 if the observation is censored, 1 otherwise.

event

Event type. 2 is death in ICU, 3 is discharge alive

pneu

Nosocomial pneumonia indicator.

adm.cens.exit

Exit times for patients discharged alive are replaced by their administrative censoring times.

age

Age at inclusion

sex

Sex. F for female and M for male

References

Beyersmann, J. and Schumacher, M. (2008). Time-dependent covariates in the proportional hazards model for competing risks. Biostatistics, 9:765--776.

Examples

Run this code
# NOT RUN {
data(icu.pneu)
# }

Run the code above in your browser using DataLab