Learn R Programming

kmi (version 0.5.5)

print.cox.kmi: Print method for cox.kmi objects

Description

Print method for cox.kmi objects.

Usage

# S3 method for cox.kmi
print(x, print.ind = FALSE, ...)

Arguments

x

An object of class cox.kmi.

print.ind

A logical specifying whether to print the results of the analyses performed on each imputed data set. By default, only the pooled estimates are printed.

Further arguments

Value

No value returned

See Also

cox.kmi, summary.cox.kmi