Provides a summary of the fitted model.
# S3 method for cox.kmi
summary(object, conf.int = 0.95, scale = 1, ...)An object of class cox.kmi.
Level of the confidence intervals. Default is 0.95
Vector of scale factors for the coefficients, default to 1. The confidence limits are for the risk change associated with one scale unit.
Further arguments
An object of class summary.cox.kmi with the following
components:
The matched call
A matrix with 5 columns including the regression coefficients, subdistribution hazard ratios, standard-errors, t-statistics and corresponding two-sided p-values.
A matrix with 4 columns that consists of the subdistribution hazard ratios, exp(-coef) and the lower and upper bounds of the confidence interval.
A list of summary.coxph objects for each
imputed data set