This data set is a random sample drawn from the SIR-3 study that aimed at analysing the effect of nosocomial infections on the length of ICU stay. Patients were included in the study if they had stayed at least 1 day in the unit. The sample includes information to assess the effect of nosocomial pneumonia on the length of stay. The endpoint is either discharge alive from the ICU or dead in the unit. These data are censoring complete as the censoring time is known for all patients.
data(icu.pneu)A data frame with 1421 observations on the following 8 variables.
idIndividual patient id.
startStart of the observation time.
stopFailure time.
statusCensoring status. 0 if the observation is censored, 1 otherwise.
eventEvent type. 2 is death in ICU, 3 is discharge alive
pneuNosocomial pneumonia indicator.
adm.cens.exitExit times for patients discharged alive are replaced by their administrative censoring times.
ageAge at inclusion
sexSex. F for female and M for male
Beyersmann, J. and Schumacher, M. (2008). Time-dependent covariates in the proportional hazards model for competing risks. Biostatistics, 9:765--776.
# NOT RUN {
data(icu.pneu)
# }
Run the code above in your browser using DataLab